// created by proto.sh from diajava/proto.lst
#define PROTO_Str  1
#define PROTO_Newline  2
#define PROTO_Skip  3
#define PROTO_Hline  4
#define PROTO_Dispolast  5
#define PROTO_Label  6
#define PROTO_String  7
#define PROTO_Checkbox  8
#define PROTO_Radio  9
#define PROTO_Button  10
#define PROTO_Button_xpm  11
#define PROTO_Button_xpmf  12
#define PROTO_Choice  13
#define PROTO_Choice_item  14
#define PROTO_List  15
#define PROTO_List_item  16
#define PROTO_Combo  17
#define PROTO_Combo_item  18
#define PROTO_Group  19
#define PROTO_Form  20
#define PROTO_Page  21
#define PROTO_Book  22
#define PROTO_MainForm  23
#define PROTO_End  24
#define PROTO_Delete  25
#define PROTO_Dump  26
#define PROTO_Icon_xpm  27
#define PROTO_Xfer_xpm  28
#define PROTO_Sidetitle  29
#define PROTO_Fill  30
#define PROTO_Formbutton  31
#define PROTO_Groupfit  32
#define PROTO_Setweightlast  33
#define PROTO_Richtext  34
#define PROTO_Password  35
#define PROTO_Buttonfill  36
#define PROTO_Enteraction  37
#define PROTO_Curfield  38
#define PROTO_Version  39
#define PROTO_Treemenu  40
#define PROTO_Treeelem  41
#define PROTO_Clist  42
#define PROTO_Clist_item  43
#define PROTO_Html  44
#define PROTO_Treesub  45
#define PROTO_Sheet  46
#define PROTO_Sheet_item  47
#define PROTO_Textarea  48
#define PROTO_Slider  49
#define PROTO_Gauge  50
#define PROTO_Setval  51
#define PROTO_Alive  52
#define PROTO_Setcontext  53
#define PROTO_Defdc  54
#define PROTO_Deffont  55
#define PROTO_Defpen  56
#define PROTO_Defbrush  57
#define PROTO_Drawline  58
#define PROTO_Drawrect  59
#define PROTO_Drawarc  60
#define PROTO_Fillrect  61
#define PROTO_Fillarc  62
#define PROTO_Menubar  63
#define PROTO_Popupmenu  64
#define PROTO_Submenu  65
#define PROTO_Menuentry  66
#define PROTO_Clear  67
#define PROTO_Drawclip  68
#define PROTO_Setcursor  69
#define PROTO_Blit  70
#define PROTO_Drawtext  71
#define PROTO_Refresh  72
#define PROTO_Menutitle  73
#define PROTO_Listen  74
#define PROTO_Prefsubmenu  75
#define PROTO_Show  76
#define PROTO_Inputgrid  77
#define PROTO_Fillpolygon  78
#define PROTO_Splash  79
#define PROTO_Hidesplash  80
#define PROTO_Deletechild  81
#define PROTO_last 81
extern const char *protostr[];
